@@ -18,14 +18,14 @@
 #ifndef _LOG4CXX_HELPERS_INTEGER_H
 #define _LOG4CXX_HELPERS_INTEGER_H
 
-#include <log4cxx/helpers/objectimpl.h>
+#include <log4cxx/helpers/object.h>
 
 
 namespace log4cxx
 {
 namespace helpers
 {
-class LOG4CXX_EXPORT Integer : public ObjectImpl
+class LOG4CXX_EXPORT Integer : public Object
 {
 		const int val;
 	public:
