@@ -27,7 +27,11 @@
 
 #include <log4cxx/basicconfigurator.h>
 #include <log4cxx/logger.h>
+#if LOG4CXX_VERSION_MAJOR > 0
+#include <log4cxx/rolling/rollingfileappender.h> 
+#else
 #include <log4cxx/rollingfileappender.h>
+#endif
 #include <log4cxx/xml/domconfigurator.h>
 #if defined(LOG4CXX_INFO_FMT)
 #define MIKTEX_LOG4CXX_12 1
