@@ -1,6 +1,6 @@
 /*
 	This is part of TeXworks, an environment for working with TeX documents
-	Copyright (C) 2010-2020  Jonathan Kew, Stefan Löffler, Charlie Sharpsteen
+	Copyright (C) 2010-2022  Jonathan Kew, Stefan Löffler, Charlie Sharpsteen
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -64,7 +64,7 @@ void ScriptAPI::SetResult(const QVariant& rval)
 
 int ScriptAPI::strlen(const QString& str) const
 {
-	return str.length();
+	return static_cast<int>(str.length());
 }
 
 QString ScriptAPI::platform() const
